
#line 2 "lex.yy.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#ifdef _LIBC
#include "namespace.h"
#endif
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/*	$NetBSD: flexint.h,v 1.3 2018/12/23 16:27:17 christos Exp $	*/

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, yy_size_t size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, yy_size_t len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (yy_size_t)(yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 149
#define YY_END_OF_BUFFER 150
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[325] =
    {   0,
        0,    0,  150,  148,  144,  147,  148,  140,  143,   93,
      109,  139,   94,   95,   90,   87,   83,   89,  110,   92,
      137,  137,   84,  146,  105,   85,  104,  117,  112,  132,
        1,    2,  100,  148,  101,  113,  132,  132,  132,  132,
      132,  132,  132,  132,  132,  132,  132,  132,  132,  132,
      132,  132,  132,  132,  132,  132,  115,  108,  116,  111,
      106,  143,    0,    0,   91,  142,    0,   86,    0,   88,
        0,   96,  134,  141,  118,    0,  133,  137,  137,    0,
        0,  136,  138,   98,  120,  103,  102,  119,  132,   97,
        0,  145,    3,  132,  132,  132,    9,  132,  132,   13,

      132,  132,   17,  132,  132,  132,   25,   27,  132,  132,
      132,   33,  132,   35,  132,  132,  132,   42,  132,  132,
       46,   47,   48,   49,   51,  132,  132,  132,  132,  132,
       69,   75,  132,  132,  132,  132,   81,  132,    0,  114,
      107,  126,  128,    0,  123,  121,  122,    0,  125,  133,
        0,    0,  135,   99,    0,    0,    4,    5,  132,  132,
      132,  132,   11,  132,  132,  132,  132,  132,  132,   20,
      132,  132,  132,  132,  132,  132,  132,  132,  132,  132,
      132,   37,   38,   39,   40,  132,  132,   44,  132,  132,
      132,   55,  132,   57,   59,  132,   61,  132,   65,  132,

      132,  132,  132,  132,  132,  132,  132,  132,   79,   80,
       82,  127,    0,  124,    0,  134,    0,  133,  135,  131,
      130,  132,    7,    8,   10,   12,  132,  132,  132,  132,
       19,   21,   22,  132,  132,   28,  132,  132,  132,   32,
      132,  132,   41,   43,   45,  132,   52,   56,  132,  132,
      132,  132,   66,  132,   68,  132,  132,  132,   73,  132,
       76,   77,  132,  129,    6,   14,  132,  132,  132,  132,
      132,   26,   29,  132,  132,  132,  132,  132,  132,  132,
       60,  132,  132,  132,  132,   71,  132,  132,   78,   15,
      132,   18,   23,  132,  132,   31,   34,  132,   50,  132,

      132,  132,  132,   63,  132,   70,   72,   74,   16,  132,
       30,   36,  132,   54,   58,  132,   64,  132,   24,  132,
       62,   67,   53,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    1,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   19,   19,
       19,   19,   19,   19,   19,   20,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   28,   28,   28,   29,   28,
       30,   30,   30,   30,   30,   30,   30,   30,   30,   31,
       32,   30,   30,   30,   30,   33,   30,   34,   30,   30,
       35,   36,   37,   38,   39,    1,   40,   41,   42,   43,

       44,   45,   46,   47,   48,   30,   49,   50,   51,   52,
       53,   54,   32,   55,   56,   57,   58,   59,   60,   61,
       62,   30,   63,   64,   65,   66,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[67] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    3,    3,
        1,    1,    1,    1,    1,    1,    1,    3,    3,    3,
        3,    3,    3,    3,    1,    1,    1,    1,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[327] =
    {   0,
        0,    0,  379,  380,  380,  380,  354,  380,    0,  356,
      355,  380,  380,  380,   54,   55,  380,   52,   51,   61,
       66,   59,  351,  380,   57,  380,   63,  380,  380,    0,
        0,    0,  337,   87,  380,  380,   47,   40,   65,   60,
       64,   75,  323,  324,   79,  318,  317,   85,   92,   46,
      325,   88,   64,  316,   99,  314,  380,   76,  380,  342,
      380,    0,  341,  340,  342,  380,  338,  380,  337,  380,
      336,  380,  122,  380,  380,  335,  129,    0,  133,  140,
      148,  380,  380,  337,  336,  380,  380,  335,    0,  380,
      119,  380,    0,   93,  309,  110,    0,  120,  314,  301,

      308,  295,  290,  293,  113,  128,  298,  125,  292,  293,
      299,    0,  290,  130,  283,  299,  119,    0,  129,  291,
        0,    0,    0,  283,    0,  286,  283,  148,  140,  289,
      146,    0,  278,  281,  286,  145,    0,  278,  308,  310,
      380,  380,  380,  306,  380,  380,  380,  192,  380,  178,
      199,  190,  197,  380,  305,  304,    0,    0,  279,  264,
      275,  274,    0,  268,  266,  281,  263,  267,  274,    0,
      266,  259,  271,  258,  269,  272,  251,  269,  262,  255,
      250,    0,    0,    0,    0,  249,  251,    0,  254,  241,
      260,    0,  251,  256,    0,  249,  245,  239,    0,  253,

      255,  240,  176,  239,  244,  247,  246,  236,    0,    0,
        0,  380,  264,  380,  206,  208,  211,  213,  215,  380,
      380,  235,    0,    0,    0,    0,  229,  228,  229,  226,
        0,    0,    0,  184,  238,    0,  231,  240,  239,    0,
      223,  229,    0,    0,    0,  222,  231,    0,  226,  211,
      214,  216,    0,  215,    0,  214,  216,  209,    0,  214,
        0,    0,  213,  380,    0,    0,  220,  210,  209,  218,
      208,    0,    0,  204,  208,  200,  216,  211,  140,  195,
        0,  198,  200,  211,  195,    0,  192,  202,    0,    0,
      185,    0,    0,  206,  202,    0,    0,  194,    0,  185,

      185,  194,  195,  167,  164,    0,    0,    0,    0,  164,
        0,    0,  148,    0,    0,  137,    0,  117,    0,  110,
        0,    0,    0,  380,  239,   93
    } ;

static const flex_int16_t yy_def[327] =
    {   0,
      324,    1,  324,  324,  324,  324,  324,  324,  325,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,   21,  324,  324,  324,  324,  324,  324,  324,  326,
      326,  326,  324,  324,  324,  324,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  324,  324,  324,  324,
      324,  325,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324,  324,   21,   21,   21,
       80,  324,  324,  324,  324,  324,  324,  324,  326,  324,
      324,  324,  326,  326,  326,  326,  326,  326,  326,  326,

      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  324,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,   80,  324,  324,  324,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,

      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  324,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,

      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,  326,  326,  326,  326,  326,  326,  326,
      326,  326,  326,    0,  324,  324
    } ;

static const flex_int16_t yy_nxt[447] =
    {   0,
        4,    5,    6,    5,    7,    8,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   25,   26,   27,   28,   29,   30,   30,   30,
       31,   30,   32,   30,   33,   34,   35,   36,    4,   37,
       38,   39,   40,   41,   42,   43,   44,   45,   30,   46,
       47,   48,   49,   50,   51,   52,   53,   54,   55,   30,
       56,   30,   57,   58,   59,   60,   65,   70,   68,   73,
       73,   66,   71,   74,   67,   69,   72,   79,   75,   85,
       86,   76,   77,   95,   78,   79,   87,   88,   91,   92,
      324,   93,   96,   80,   81,   89,  139,   82,   94,   83,

      126,   97,  127,  102,   98,   80,   80,   80,   80,   81,
       80,   99,  103,  104,  107,  105,  132,  100,  133,  101,
       91,   92,  108,  112,  106,  134,   83,  109,  117,  113,
      114,  129,  118,  121,  122,  157,  130,  119,  136,  140,
       73,   73,  120,  123,  131,  124,  125,  150,  150,  137,
      148,   79,  160,  323,  158,  170,  324,  151,   80,   80,
      322,  152,  161,  152,  324,  148,  153,  153,   80,  162,
      171,  324,  151,  163,  175,  172,  176,  181,  185,  186,
      321,  187,  300,   80,  173,  188,  182,  193,  203,  194,
      199,  200,  195,  201,  209,  301,  150,  150,  204,  210,

      205,  196,  320,  197,  198,  215,  151,  215,  219,  219,
      216,  216,  217,  319,  217,  153,  153,  218,  218,  256,
      318,  151,  317,  257,  216,  216,  216,  216,  258,  218,
      218,  218,  218,  219,  219,  270,  316,  315,  271,   62,
      314,   62,  313,  312,  311,  310,  309,  308,  307,  306,
      305,  304,  303,  302,  299,  298,  297,  296,  295,  294,
      293,  292,  291,  290,  289,  288,  287,  286,  285,  284,
      283,  282,  281,  280,  279,  278,  277,  276,  275,  274,
      273,  272,  269,  268,  267,  266,  265,  264,  263,  262,
      261,  260,  259,  255,  254,  253,  252,  251,  250,  249,

      248,  247,  246,  245,  244,  243,  242,  241,  240,  239,
      238,  237,  236,  235,  234,  233,  232,  231,  230,  229,
      228,  227,  226,  225,  224,  223,  222,  221,  220,  214,
      213,  212,  211,  208,  207,  206,  202,  192,  191,  190,
      189,  184,  183,  180,  179,  178,  177,  174,  169,  168,
      167,  166,  165,  164,  159,  156,  155,  154,  149,  147,
      146,  145,  144,  143,  142,  141,  138,  135,  128,  116,
      115,  111,  110,   90,   84,   64,   63,   61,  324,    3,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,

      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324
    } ;

static const flex_int16_t yy_chk[447] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,   15,   18,   16,   19,
       19,   15,   18,   20,   15,   16,   18,   22,   20,   25,
       25,   20,   21,   38,   21,   21,   27,   27,   34,   34,
       22,   37,   38,   21,   21,  326,   58,   21,   37,   21,

       50,   38,   50,   40,   39,   21,   21,   21,   21,   21,
       21,   39,   40,   41,   42,   41,   53,   39,   53,   39,
       91,   91,   42,   45,   41,   53,   21,   42,   48,   45,
       45,   52,   48,   49,   49,   94,   52,   48,   55,   58,
       73,   73,   48,   49,   52,   49,   49,   77,   77,   55,
       73,   79,   96,  320,   94,  105,   80,   77,   80,   80,
      318,   81,   96,   81,   79,   73,   81,   81,   80,   98,
      105,   80,   77,   98,  108,  106,  108,  114,  117,  117,
      316,  119,  279,   80,  106,  119,  114,  128,  131,  128,
      129,  129,  128,  129,  136,  279,  150,  150,  131,  136,

      131,  128,  313,  128,  128,  148,  150,  148,  152,  152,
      148,  148,  151,  310,  151,  153,  153,  151,  151,  203,
      305,  150,  304,  203,  215,  215,  216,  216,  203,  217,
      217,  218,  218,  219,  219,  234,  303,  302,  234,  325,
      301,  325,  300,  298,  295,  294,  291,  288,  287,  285,
      284,  283,  282,  280,  278,  277,  276,  275,  274,  271,
      270,  269,  268,  267,  263,  260,  258,  257,  256,  254,
      252,  251,  250,  249,  247,  246,  242,  241,  239,  238,
      237,  235,  230,  229,  228,  227,  222,  213,  208,  207,
      206,  205,  204,  202,  201,  200,  198,  197,  196,  194,

      193,  191,  190,  189,  187,  186,  181,  180,  179,  178,
      177,  176,  175,  174,  173,  172,  171,  169,  168,  167,
      166,  165,  164,  162,  161,  160,  159,  156,  155,  144,
      140,  139,  138,  135,  134,  133,  130,  127,  126,  124,
      120,  116,  115,  113,  111,  110,  109,  107,  104,  103,
      102,  101,  100,   99,   95,   88,   85,   84,   76,   71,
       69,   67,   65,   64,   63,   60,   56,   54,   51,   47,
       46,   44,   43,   33,   23,   11,   10,    7,    3,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,

      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324,  324,  324,  324,  324,
      324,  324,  324,  324,  324,  324
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "tokens.l"
/*  lex spec for SR  */
/*  configuration options  */
/*  definitions to aid in specifying real constants  */
#line 22 "tokens.l"



#ifdef __CLCC__
#pragma Warning_level(0)
#endif


#include "compiler.h"
#include <ctype.h>

#define YYSTYPE Nodeptr
#include "tokens.h"

/*  hex to integer mapping (use low 5 bits of ascii char as subscript)  */
static unsigned xci[] = 
    {0,10,11,12,13,14,15,0,0,0,0,0,0,0,0,0,0,1,2,3,4,5,6,7,8,9};



static int doint	PARAMS ((int base));
static int literal	PARAMS ((int tk, Operator o, Sigptr g, int value));
static int doid		PARAMS ((NOARGS));
static int doreal	PARAMS ((NOARGS));
static int chrlit	PARAMS ((NOARGS));
static int strlit	PARAMS ((NOARGS));
static int escape	PARAMS ((NOARGS));
static void comment	PARAMS ((NOARGS));
static void toolong	PARAMS ((NOARGS));



/********************************  NOTE  *******************************/

/*	when adding or changing keywords, also update
	../srgrind/srgrind.sh and ../srtex/scan.l	*/

/***********************************************************************/

#line 695 "lex.yy.c"
#line 696 "lex.yy.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			yy_size_t yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		yy_size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 63 "tokens.l"


#line 916 "lex.yy.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 325 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 380 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 65 "tokens.l"
return TK_P;
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 66 "tokens.l"
return TK_V;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 67 "tokens.l"
return TK_AF;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 68 "tokens.l"
return TK_AND;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 69 "tokens.l"
return TK_ANY;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 70 "tokens.l"
return TK_BEGIN;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 71 "tokens.l"
return TK_BODY;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 72 "tokens.l"
return TK_BOOL;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 73 "tokens.l"
return TK_BY;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 74 "tokens.l"
return TK_CALL;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 75 "tokens.l"
return TK_CAP;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 76 "tokens.l"
return TK_CHAR;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 77 "tokens.l"
return TK_CO;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 78 "tokens.l"
return TK_CONST;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 79 "tokens.l"
return TK_CREATE;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 80 "tokens.l"
return TK_DESTROY;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 81 "tokens.l"
return TK_DO;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 82 "tokens.l"
return TK_DOWNTO;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 83 "tokens.l"
return TK_ELSE;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 84 "tokens.l"
return TK_END;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 85 "tokens.l"
return TK_ENUM;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 86 "tokens.l"
return TK_EXIT;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 87 "tokens.l"
return TK_EXTEND;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 88 "tokens.l"
return TK_EXTERNAL;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 89 "tokens.l"
return TK_FA;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 90 "tokens.l"
return literal (TK_BLIT, O_BLIT, bool_sig, FALSE);
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 91 "tokens.l"
return TK_FI;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 92 "tokens.l"
return TK_FILE;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 93 "tokens.l"
return TK_FINAL;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 94 "tokens.l"
return TK_FORWARD;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 95 "tokens.l"
return TK_GLOBAL;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 96 "tokens.l"
return TK_HIGH;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 97 "tokens.l"
return TK_IF;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 98 "tokens.l"
return TK_IMPORT;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 99 "tokens.l"
return TK_IN;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 100 "tokens.l"
return TK_INITIAL;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 101 "tokens.l"
return TK_INT;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 102 "tokens.l"
return TK_LOW;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 103 "tokens.l"
return TK_MOD;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 104 "tokens.l"
return TK_NEW;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 105 "tokens.l"
return TK_NEXT;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 106 "tokens.l"
return TK_NI;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 107 "tokens.l"
return literal (TK_NLIT, O_NLIT, nlit_sig, NOOP_SEQN);
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 108 "tokens.l"
return TK_NOT;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 109 "tokens.l"
return literal (TK_NLIT, O_NLIT, nlit_sig, NULL_SEQN);
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 110 "tokens.l"
return TK_OC;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 111 "tokens.l"
return TK_OD;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 112 "tokens.l"
return TK_ON;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 113 "tokens.l"
return TK_OP;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 114 "tokens.l"
return TK_OPTYPE;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 115 "tokens.l"
return TK_OR;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 116 "tokens.l"
return TK_PROC;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 117 "tokens.l"
return TK_PROCEDURE;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 118 "tokens.l"
return TK_PROCESS;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 119 "tokens.l"
return TK_PTR;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 120 "tokens.l"
return TK_REAL;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 121 "tokens.l"
return TK_REC;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 122 "tokens.l"
return TK_RECEIVE;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 123 "tokens.l"
return TK_REF;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 124 "tokens.l"
return TK_REPLY;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 125 "tokens.l"
return TK_RES;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 126 "tokens.l"
return TK_RESOURCE;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 127 "tokens.l"
return TK_RETURN;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 128 "tokens.l"
return TK_RETURNS;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 129 "tokens.l"
return TK_SEM;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 130 "tokens.l"
return TK_SEND;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 131 "tokens.l"
return TK_SEPARATE;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 132 "tokens.l"
return TK_SKIP;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 133 "tokens.l"
return TK_SUCHTHAT;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 134 "tokens.l"
return literal (TK_FLIT, O_FLIT, file_sig, STDERR);
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 135 "tokens.l"
return literal (TK_FLIT, O_FLIT, file_sig, STDIN);
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 136 "tokens.l"
return literal (TK_FLIT, O_FLIT, file_sig, STDOUT);
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 137 "tokens.l"
return TK_STOP;	
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 138 "tokens.l"
return TK_STRING;	
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 139 "tokens.l"
return TK_TO;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 140 "tokens.l"
return literal (TK_BLIT, O_BLIT, bool_sig, TRUE);
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 141 "tokens.l"
return TK_TYPE;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 142 "tokens.l"
return TK_UNION;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 143 "tokens.l"
return TK_VAL;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 144 "tokens.l"
return TK_VAR;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 145 "tokens.l"
return TK_VM;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 146 "tokens.l"
return TK_XOR;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 148 "tokens.l"
return TK_COMMA;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 149 "tokens.l"
return TK_COLON;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 150 "tokens.l"
return TK_EQ;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 151 "tokens.l"
return TK_INCR;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 152 "tokens.l"
return TK_PLUS;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 153 "tokens.l"
return TK_DECR;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 154 "tokens.l"
return TK_MINUS;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 155 "tokens.l"
return TK_ASTER;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 156 "tokens.l"
return TK_EXPON;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 157 "tokens.l"
return TK_DIV;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 158 "tokens.l"
return TK_REMDR;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 159 "tokens.l"
return TK_LPAREN;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 160 "tokens.l"
return TK_RPAREN;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 161 "tokens.l"
return TK_ARROW;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 162 "tokens.l"
return TK_SQUARE;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 163 "tokens.l"
return TK_ASSIGN;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 164 "tokens.l"
return TK_SWAP;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 165 "tokens.l"
return TK_LBRACKET;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 166 "tokens.l"
return TK_RBRACKET;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 167 "tokens.l"
return TK_GE;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 168 "tokens.l"
return TK_LE;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 169 "tokens.l"
return TK_GT;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 170 "tokens.l"
return TK_LT;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 171 "tokens.l"
return TK_NE;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 172 "tokens.l"
return TK_NE;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 173 "tokens.l"
return TK_OR;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 174 "tokens.l"
return TK_AND;
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 175 "tokens.l"
return TK_PERIOD;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 176 "tokens.l"
return TK_NOT;
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 177 "tokens.l"
return TK_ADDR;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 178 "tokens.l"
return TK_HAT;
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 179 "tokens.l"
return TK_CONCAT;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 180 "tokens.l"
return TK_LBRACE;
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 181 "tokens.l"
return TK_RBRACE;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 182 "tokens.l"
return TK_QMARK;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 183 "tokens.l"
return TK_PARALLEL;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 184 "tokens.l"
return TK_RSHIFT;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 185 "tokens.l"
return TK_LSHIFT;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 187 "tokens.l"
return TK_AUG_PLUS;
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 188 "tokens.l"
return TK_AUG_MINUS;
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 189 "tokens.l"
return TK_AUG_ASTER;
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 190 "tokens.l"
return TK_AUG_EXPON;
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 191 "tokens.l"
return TK_AUG_DIV;
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 192 "tokens.l"
return TK_AUG_REMDR;
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 193 "tokens.l"
return TK_AUG_OR;
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 194 "tokens.l"
return TK_AUG_AND;
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 195 "tokens.l"
return TK_AUG_CONCAT;
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 196 "tokens.l"
return TK_AUG_RSHIFT;
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 197 "tokens.l"
return TK_AUG_LSHIFT;
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 199 "tokens.l"
return doid();		/* identifier */
	YY_BREAK
case 133:
#line 201 "tokens.l"
case 134:
#line 202 "tokens.l"
case 135:
YY_RULE_SETUP
#line 202 "tokens.l"
return doreal();	/* real literal */
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 203 "tokens.l"
return doint(8);	/* base 8 integer literal */
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 204 "tokens.l"
return doint(10);	/* base 10 integer literal */
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 205 "tokens.l"
return doint(16);	/* base 16 integer literal */
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 206 "tokens.l"
return chrlit();	/* character literal */
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 207 "tokens.l"
return strlit();	/* string literal */
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 209 "tokens.l"
comment();		/* block comment */
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 210 "tokens.l"
FATAL ("comment terminator outside comment");
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 211 "tokens.l"
;			/* line comment */
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 212 "tokens.l"
;			/* whitespace */
	YY_BREAK
case 145:
/* rule 145 can match eol */
YY_RULE_SETUP
#line 213 "tokens.l"
newlines++;		/* line continuation */
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 215 "tokens.l"
return TK_SEPARATOR;
	YY_BREAK
case 147:
/* rule 147 can match eol */
YY_RULE_SETUP
#line 216 "tokens.l"
{ newlines++;	return TK_NEWLINE; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 218 "tokens.l"
err (srclocn, "illegal character `%s'", (char*)yytext);
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 221 "tokens.l"
ECHO;
	YY_BREAK
#line 1714 "lex.yy.c"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	yy_size_t number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (yy_size_t) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 325 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 325 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 324);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp )
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		yy_size_t number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 221 "tokens.l"




#ifndef YYLMAX
#define YYLMAX 500
#endif

extern int yydebug;		/* defined by yacc */
extern Nodeptr yylval;		/* defined by yacc */



/*  doid() -- process identifier  */

static int
doid ()
{
#ifdef YYDEBUG
    if (yydebug)
	fprintf (stderr, "`%s' ", yytext);
#endif /*YYDEBUG*/

    if (yyleng >= YYLMAX)
	toolong ();
    yylval = idnode ((char *) yytext);
    return TK_ID;
}



/*  doreal() -- interpret real literal  */

static int
doreal ()
{
    Real v;

    if (yyleng >= YYLMAX)
	toolong ();
    sscanf ((char *) yytext, "%lf", &v);
    yylval = realnode (v);
    return TK_RLIT;
}



/*  doint (base) -- interpret integer literal  */

static int
doint (base)
int base;
{
    char *p, *q;
    int n;

    if (yyleng >= YYLMAX)
	toolong ();
    p = (char *) yytext;		/* string pointer */
    q = (char *) (yytext + yyleng);	/* end+1 of string */
    if (base != 10)			/* chop "q" or "x" if not base 10 */
	q--;
    n = 0;
    while (p < q)			/* process each digit in turn */
	n = base * n + xci [*p++ & 037];
    return literal (TK_ILIT, O_ILIT, int_sig, n);
}



/*  literal (token, opr, sig, value) -- construct token for literal value  */

static int
literal (token, opr, sig, value)
int token;
Operator opr;
Sigptr sig;
int value;
{
    yylval = intnode (value);		/* value = integer value */
    yylval->e_opr = opr;		/* opr = node identifier */
    yylval->e_sig = sig;		/* sig = literal's signature */
    return token;			/* token = lex token */
}



/*  chrlit() -- process a character ('c') literal  */

static int
chrlit ()
{
    int c, d;

    c = input();
    if (c == '\n') {
	unput (c);
	FATAL ("newline in character literal");
	return literal (TK_CLIT, O_CLIT, char_sig, 0);
    }
    if (c == '\'') {
	FATAL ("empty character literal");
	return literal (TK_CLIT, O_CLIT, char_sig, 0);
    }

    if (c == '\\')
	c = escape ();

    d = input();			/* find trailing delimiter */
    if (d != '\'') {
	FATAL ("character literal contains multiple characters");
	while (d != '\'' && d != '\n' && d != 0)
	    d = input();
	if (d != 0)
	    unput (d);
    }

    return literal (TK_CLIT, O_CLIT, char_sig, c);
}



/*  strlit() -- process a string ("abc") literal  */

static int
strlit ()
{
    char buf [YYLMAX + 1];
    char *p, *q;
    int c, n, len;
    String *s;

    p = buf;
    q = p + YYLMAX;
    len = 0;
    for (c = input(); c != '"'; c = input()) {
	if (c == '\n' || c == '\0') {
	    if (c != '\0')
		unput (c);
	    FATAL ("unterminated string");
	    break;
	}
	if (c == '\\') 
	    c = escape ();
	if (p < q)
	    *p++ = c;
	len++;
    }
    *p++ = '\0';

    if (len > YYLMAX) {
	FATAL ("string too long");
	len = YYLMAX;
    }

    n = len + STRING_OVH;
    s = (String *) ralloc (n);
    s->size = n;
    s->length = len;
    memcpy (DATA (s), buf, len + 1);

    yylval = newnode (O_SLIT);
    yylval->e_sptr = s;
    yylval->e_sig = newsig (T_STRING, NULLSIG);
    yylval->e_sig->g_lb = intnode (1);
    yylval->e_sig->g_ub = intnode (len);
    return TK_SLIT;
}



/*  escape() -- interpret sequence following '\' and return resulting char  */

static int
escape ()
{
    int ntok;
    unsigned bitp;

    switch (ntok = input ()) {
    case 'a'  :     return '\007';		/* alert */
    case 'b'  :     return '\b';		/* backspace */
    case 'e'  :     return '\033';		/* escape */
    case 'f'  :     return '\f';		/* form feed */
    case 'n'  :     return '\n';		/* newline */
    case 'r'  :     return '\r';		/* return */
    case 't'  :     return '\t';		/* tab */
    case 'v'  :     return '\013';		/* vertical tab */
    case '\n' :	    newlines++; return '\n';	/* newline */
    case 'x':
	ntok = input ();
	if (isdigit(ntok) || (ntok>='a'&&ntok<='f') || (ntok>='A'&&ntok<='F')) {
	    bitp = xci [ntok & 037];
	    ntok = input ();
	    if (isdigit(ntok)||(ntok>='a'&&ntok<='f')||(ntok>='A'&&ntok<='F')) {
		return (bitp << 4) | xci [ntok & 037];
	    } else {
		unput (ntok);
		return bitp;
	    }
	} else {
	    unput (ntok);
	    return 0;
	}
    default:
	if ('0' <= ntok && ntok <= '7') {
	    bitp = ntok - '0';
	    if ((ntok = input ()) >= '0' && ntok <= '7') {
		bitp = (bitp << 3) | (ntok - '0');
		if ((ntok = input ()) >= '0' && ntok <= '7')
		    bitp = (bitp << 3) | (ntok - '0');
		else
		    unput (ntok);
	    } else
		unput (ntok);
	    return (int) bitp;
	} else
	    return ntok;
    }
}



/*  comment() -- process a block comment, /+* through *+/   */

static void
comment ()
{
    int c;

    c = input ();
    for (;;) {
	switch (c)  {
	    case 0:
	    case EOF:
		FATAL ("unterminated comment at EOF");
		return;
	    case '\n':
		newlines++;
		c = input ();
		continue;
	    case '/':
		c = input ();
		if (c == '*') {
		    comment ();
		    c = input ();
		}
		continue;
	    case '*':
		c = input ();
		if (c == '/')
		    return;
		continue;
	    default:
		c = input ();
		continue;
	}
    }
}



/*  toolong () -- diagnose a token that is too long.
 *
 *  We don't try to recover; lex has already overwritten memory.
 *  If we're lucky we can issue a diagnostic on the way out.
 */
static void
toolong ()
{
    write (2, "token too long: ", 16);
    write (2, yytext, 30);
    write (2, "...\n", 4);
    _exit (1);
}



/*  yyref () -- return pointer to yytext buffer.
 *
 *  This function allows other files to be ignorant of whether
 *  yytext is defined as char* or char[].
 */
char *
yyref ()
{
    return (char *) yytext;	/* must cast; might be unsigned */
}



/*  yywrap () -- handle EOF.
 *
 *  Supplying yywrap eliminates the need to link with the lex library.
 */
int
yywrap ()
{
    return 1;		/* indicates no additional file; return EOF token */
}



#ifdef FLEX_SCANNER

/*************  input switching for flex  ******************/

void *
lexfrom (fp)
FILE *fp;
{
    void *oldbuf;

    oldbuf = YY_CURRENT_BUFFER;
    yy_switch_to_buffer (yy_create_buffer (fp, YY_BUF_SIZE));
    return oldbuf;
}

void
lexrevert (old)
void *old;
{
    yy_delete_buffer (YY_CURRENT_BUFFER);
    yy_switch_to_buffer ((YY_BUFFER_STATE) old);
}



# else	/* not FLEX_SCANNER */

/*************  input switching for lex  ******************/

void *
lexfrom (fp)
FILE *fp;
{
    void *old;

    old = yyin;
    yyin = fp;
    return old;
}

void
lexrevert (old)
void *old;
{
    yyin = (FILE *) old;
}


#endif  /* FLEX_SCANNER */

